{
  nix-doom-emacs-module,
  pkgs,
  ...
}: {
  users.users.tristand = {
    isNormalUser = true;
    description = "Tristan Druyen";
    extraGroups = ["networkmanager" "wheel" "libvirtd"];
    shell = pkgs.fish;
    home = "/home/tristand";
  };

  home-manager.users.tristand = {pkgs, ...}: {
    imports = [
      nix-doom-emacs-module
    ];

    nix = {
      settings.experimental-features = ["nix-command" "flakes"];
    };

    dconf.settings = {
      "org/virt-manager/virt-manager/connections" = {
        autoconnect = ["qemu:///system"];
        uris = ["qemu:///system"];
      };
    };

    programs.alacritty = {
      enable = true;
      settings = {
        window.opacity = 0.88;
        window.dimensions = {
          lines = 40;
          columns = 150;
        };
      };
    };

    programs.doom-emacs = {
      enable = true;
      doomPrivateDir = ./doom.d;
      emacsPackage = pkgs.emacs;
    };
    services.emacs = {
      enable = true;
      defaultEditor = true;
    };

    programs.fish.enable = true;

    programs.git = {
      enable = true;
      userName = "Tristan Druyen";
      userEmail = "tristan@vault81.de";
      aliases = {
        ci = "commit";
        co = "checkout";
        s = "status";
      };
    };

    home.packages = with pkgs; [
      alejandra
      atool
      alacritty
      aspell
      aspellDicts.en
      aspellDicts.en-computers
      aspellDicts.en-science
      aspellDicts.de
      bitwarden
      binutils
      brave
      btop
      direnv
      firefox
      jellyfin-media-player
      neofetch
      kate
      rust-motd
      (ripgrep.override {withPCRE2 = true;})
      signal-desktop
      statix
      tailscale
      tokei
      thunderbird
      zellij
    ];

    home.sessionVariables = {
      BROWSER = "firefox";
      TERMINAL = "alacritty";
    };

    home.stateVersion = "23.05";
  };
}
